---
title: <span class="badge object-type-scalar"></span> PetaHashesPerSecond
---
# <span class="badge object-type-scalar"></span> PetaHashesPerSecond

Hash rate: petahashes/sec

## Definition

```python
# Hash rate: petahashes/sec
PetaHashesPerSecond: typing.Literal["PHs"] = "PHs"
```
